@@ -9,17 +9,17 @@
 """
 
 __app_name__ = "word-search"
-__version__ = "1.0.9.post2"
+__version__ = "1.1.1"
 
-from typing import Optional
+from pathlib import Path
+from typing import Optional, Union
 
 from word_search_generator import config, export, generate, utils
-from word_search_generator.types import Key, Puzzle, SavePath
+from word_search_generator.types import Key, Puzzle
 
 
 class WordSearch:
-    """This class represents a WordSearch object
-    used for generating Word Search puzzles."""
+    """This class represents a WordSearch object."""
 
     def __init__(
         self, words: str, level: Optional[int] = None, size: Optional[int] = None
@@ -27,8 +27,8 @@ class WordSearch:
         """Initializa a Word Search puzzle.
 
         Args:
-            words (str): A string of words separated by spaces, commas, or
-            new lines and limited to 30 word max. Will be trimmed if more.
+            words (str): words (str): A string of words separated by spaces, commas,
+            or new lines and limited to 30 word max. Will be trimmed if more.
             level (Optional[int], optional): Difficulty level. Defaults to None.
             size (Optional[int], optional): Puzzle size. Defaults to None.
         """
@@ -64,6 +64,7 @@ class WordSearch:
     @level.setter
     def level(self, val: int):
         """Set the difficulty level of the word search.
+
         Level 1 (Easy): Words can go forward in directions
         EAST (E), or SOUTH (S).
         Puzzle size is small by default.
@@ -127,7 +128,7 @@ class WordSearch:
     def generate(
         self, level: Optional[int] = None, size: Optional[int] = None
     ) -> Puzzle:
-        """Generate a word search puzzle using `self.words`.
+        """_summary_
 
         Args:
             level (Optional[int], optional): Difficulty level. Defaults to None.
@@ -149,40 +150,54 @@ class WordSearch:
 
         return self.puzzle
 
-    def show_solution(self):
-        """Show the current puzzle solution."""
+    def show(self, solution: bool = False):
+        """Show the current puzzle 'prettified' with or without the solution.
+
+        Args:
+            solution (bool, optional): Highlight the hidden words. Defaults to False.
+        """
+        if solution:
+            header = utils.make_header(self.puzzle, "PUZZLE SOLUTION")
+            output_puzzle = utils.highlight_solution(
+                self.puzzle, solution=self.solution
+            )
+        else:
+            header = utils.make_header(self.puzzle, "WORD SEARCH")
+            output_puzzle = self.puzzle
+
         print(
             f"""
-** WORD SEARCH SOLUTION **
+{header}
+{utils.stringify(output_puzzle)}
 
-{utils.stringify(self.solution)}"""
+Find these words: {utils.get_word_list_str(self.key)}
+
+* Words can go {utils.get_level_dirs_str(self.level)}.
+
+Answer Key: {utils.get_answer_key_str(self.key)}"""
         )
 
-    def save(self, path: SavePath = None, format: str = "pdf") -> str:
+    def save(self, path: Union[str, Path]) -> str:
         """Save the current puzzle to a file.
 
         Args:
-            path (SavePath, optional): A filename (string) or
-            pathlib.Path object. Defaults to None.
-            format (str, optional): Save file format (csv or pdf). Defaults to "pdf".
-
-        Raises:
-            ValueError: Format must be either 'csv' or 'pdf'.
+            path (Union[str, Path]): A file save path.
 
         Returns:
             str: Final save path of the file.
         """
-        # check validity of format
-        if format.lower() not in ["csv", "pdf"]:
-            raise ValueError("Format must be either 'csv' or 'pdf'")
-        ftype = ".pdf" if format.lower() == "pdf" else ".csv"
-        # validate export path
-        fpath = export.validate_path(path, ftype)
-        # write the file
-        if ftype == ".csv":
-            saved_file = export.write_csv_file(fpath, self.puzzle, self.key, self.level)
+        # check type of path provided
+        if isinstance(path, Path):
+            ftype = "csv" if ".csv" in path.name.lower() else "pdf"
         else:
-            saved_file = export.write_pdf_file(fpath, self.puzzle, self.key, self.level)
+            ftype = "csv" if ".csv" in path.lower() else "pdf"
+        # validate export path
+        path = export.validate_path(path)
+        # write the file
+        if ftype == "csv":
+            saved_file = export.write_csv_file(path, self.puzzle, self.key, self.level)
+        else:
+            saved_file = export.write_pdf_file(path, self.puzzle, self.key, self.level)
         # return saved file path
         return str(saved_file)
 
@@ -190,7 +205,8 @@ class WordSearch:
         """Add new words to the puzzle.
 
         Args:
-            words (str): A string of words separated by spaces, commas, or new lines.
+            words (str): A string of words separated by
+            spaces, commas, or new lines.
 
         Returns:
             set[str]: An updated set of words.
@@ -204,7 +220,8 @@ class WordSearch:
         """Remove words from the puzzle.
 
         Args:
-            words (str): A string of words separated by spaces, commas, or new lines.
+            words (str): A string of words separated by
+            spaces, commas, or new lines.
 
         Returns:
             set[str]: An updated set of words.
@@ -218,7 +235,8 @@ class WordSearch:
         """Replace all words in the puzzle.
 
         Args:
-            words (str): A string of words separated by spaces, commas, or new lines.
+            words (str): A string of words separated by
+            spaces, commas, or new lines.
 
         Returns:
             [type]: An updated set of words.
@@ -239,9 +257,9 @@ class WordSearch:
         return f"{self.__class__.__name__}('{self.words}')"
 
     def __str__(self):
+        header = utils.make_header(self.puzzle, "WORD SEARCH")
         return f"""
-** WORD SEARCH PUZZLE **
-
+{header}
 {utils.stringify(self.puzzle)}
 
 Find these words: {utils.get_word_list_str(self.key)}
